import { DBSchema, IDBPDatabase } from 'idb';
import { NgxHttpGetStorable } from '../models/ngx-http-get-storable.model';
import * as i0 from "@angular/core";
export declare const NGX_HTTP_GET_SHELL_DB = "ngx-http-get-shell";
export declare const NGX_HTTP_GET_SHELL_STORE = "ngx-http-get-shell-cache";
export declare const NGX_HTTP_GET_SHELL_INDEXED_KEY = "expires";
export interface HttpGetCacheDbSchema extends DBSchema {
    [NGX_HTTP_GET_SHELL_STORE]: {
        value: NgxHttpGetStorable<any>;
        key: string;
        indexes: {
            [NGX_HTTP_GET_SHELL_INDEXED_KEY]: number;
        };
    };
}
/**
 * This service handles client-side indexed db storage read/write APIs
 */
export declare class IndexedDbService {
    static db: IDBPDatabase<HttpGetCacheDbSchema>;
    private _db;
    constructor();
    /**
     * Cleans up the database by removing expired items
     */
    static cleanup(db: IDBPDatabase<HttpGetCacheDbSchema>): Promise<void>;
    /**
     * Adds an item to the database
     * @param key The key to store the value under
     * @param value The value to store
     * @param expires The time in milliseconds until the value expires
     * @returns The stored key
     */
    setItem<T>(key: string, value: T, expires: number): Promise<string>;
    /**
     * Gets an item from the database
     * @param key The key to retrieve the value from
     * @returns The stored value
     */
    getItem<T>(key: string): Promise<T>;
    /**
     * Deletes an item from the database
     * @param key The key to delete
     */
    removeItem(key: string): Promise<void>;
    /**
     * Clear all items from the database
     */
    clearAll(): Promise<void>;
    /**
     * The the indexed db instance used by this service
     * @returns Indexed db instance
     */
    getDb(): IDBPDatabase<HttpGetCacheDbSchema>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IndexedDbService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<IndexedDbService>;
}
